if select(2,UnitClass("player")) ~= "MONK" then return end
local LibStub = LibStub
local AceAddon = LibStub("AceAddon-3.0")
local AceLocale = LibStub("AceLocale-3.0")
local AceDBOptions = LibStub("AceDBOptions-3.0")
local AceConfig = LibStub("AceConfig-3.0")
local AceConfigDialog = LibStub("AceConfigDialog-3.0")

local RemUplift = AceAddon:GetAddon("RemUplift")
local RemUplift_Options = AceAddon:NewAddon("RemUplift_Options")
local L = AceLocale:GetLocale("RemUplift_Options")
local LSM = LibStub("LibSharedMedia-3.0")
local string_match = string.match
local string_format = string.format
local max = max
local min = min
local GetSpellInfo = GetSpellInfo
--------------------------------------------------------------------------------------
local cvar_width,cvar_height = string_match(GetCVar("gxResolution"), "(%d+)x(%d+)")
cvar_width = tonumber(cvar_width)
cvar_height = tonumber(cvar_height)
local cvar_min = min(cvar_width,cvar_height)

local order = 0
local function get_order()
	local temp = order
	order = order +1
	return temp
end

local options =
{
	type = "group",
	order = get_order(),
	name = "RemUplift",
	args =
	{
		Lock =
		{
			order = get_order(),
			name = L["Lock"],
			desc = L["Locks the positions of the frames"],
			type = "toggle",
			set = function(info,val)
				RemUplift.db.profile.lock = val
				RemUplift:UpdateLock()
			end,
			get = function(info) return RemUplift.db.profile.lock end,
			width = "full",
		},
		RefreshRate =
		{
			type = "range",
			order = get_order(),
			name = L["Refresh Rate"],
			min = 0,
			max = 2,
			step = 0.01,
			get = function () return RemUplift.db.profile.refreshRate end,
			set = function (_, v)
				RemUplift.db.profile.refreshRate = v
				RemUplift:UpdateRefreshRate()
			end,
			width = "full"
		},
		Rem =
		{
			order = get_order(),
			name = GetSpellInfo(115151),
			type = "group",
			args =
			{ 
				LeftPos = 
				{
					type = "range",
					order = get_order(),
					name = L["Left Position"],
					min = 0,
					max = cvar_width,
					step = 0.1,
					get = function () return RemUplift.db.profile.rem_pos_left end,
					set = function (_, v)
						RemUplift.db.profile.rem_pos_left = v
						RemUplift:UpdateRemIconPosition()
					end
				},
				TopPos = 
				{
					type = "range",
					order = get_order(),
					name = L["Top Position"],
					min = 0,
					max = cvar_height,
					step = 0.1,
					get = function () return RemUplift.db.profile.rem_pos_top end,
					set = function (_, v)
						RemUplift.db.profile.rem_pos_top = v
						RemUplift:UpdateRemIconPosition()
					end
				},
				IconSize =
				{
					type = "range",
					order = get_order(),
					name = L["Size"],
					min = 10,
					max = cvar_min,
					step = 0.1,
					get = function () return RemUplift.db.profile.iconSize end,
					set = function (_, v)
						RemUplift.db.profile.iconSize = v
						RemUplift:UpdateRemIconSize()
					end
				},
				Counter =
				{
					order = get_order(),
					type = "description",
					name = L["Counter"],
					fontSize = "medium",
					width = "full",
				},
				CounterFont =
				{
					type = 'select',
					dialogControl = 'LSM30_Font',
					name = L["Font"],
					values = LSM:HashTable("font"),
					order = get_order(),
					get = function()
						return RemUplift.db.profile.remCounterFont
					end,
					set = function(_,v)
						RemUplift.db.profile.remCounterFont = v
						RemUplift:UpdateRemCounterFont()
					end,
				},
				CounterFontSize =
				{
					type = "range",
					order = get_order(),
					name = L["Font Size"],
					min = 0.1,
					max = 100,
					step = 0.1,
					get = function () return RemUplift.db.profile.remCounterFontSize end,
					set = function (_, v)
						RemUplift.db.profile.remCounterFontSize = v
						RemUplift:UpdateRemCounterFont()
					end
				},
				MinDuration =
				{
					order = get_order(),
					type = "description",
					name = L["Min Duration"],
					fontSize = "medium",
					width = "full",
				},
				MinDurationFont =
				{
					type = 'select',
					dialogControl = 'LSM30_Font',
					name = L["Font"],
					values = LSM:HashTable("font"),
					order = get_order(),
					get = function()
						return RemUplift.db.profile.remMinDurationFont
					end,
					set = function(_,v)
						RemUplift.db.profile.remMinDurationFont = v
						RemUplift:UpdateRemMinDurationFont()
					end,
				},
				MinDurationFontSize =
				{
					type = "range",
					order = get_order(),
					name = L["Font Size"],
					min = 0.1,
					max = 100,
					step = 0.1,
					get = function () return RemUplift.db.profile.remMinDurationFontSize end,
					set = function (_, v)
						RemUplift.db.profile.remMinDurationFontSize = v
						RemUplift:UpdateRemMinDurationFont()
					end
				},
			}
		},
		Uplift =
		{
			order = get_order(),
			name = GetSpellInfo(116670),
			type = "group",
			args =
			{
				LeftPos = 
				{
					type = "range",
					order = get_order(),
					name = L["Left Position"],
					min = 0,
					max = cvar_width,
					step = 0.1,
					get = function () return RemUplift.db.profile.uplift_pos_left end,
					set = function (_, v)
						RemUplift.db.profile.uplift_pos_left = v
						RemUplift:UpdateUpliftStatusBarPosition()
					end
				},
				TopPos = 
				{
					type = "range",
					order = get_order(),
					name = L["Top Position"],
					min = 0,
					max = cvar_height,
					step = 0.1,
					get = function () return RemUplift.db.profile.uplift_pos_top end,
					set = function (_, v)
						RemUplift.db.profile.uplift_pos_top = v
						RemUplift:UpdateUpliftStatusBarPosition()
					end
				},
				BarWidth =
				{
					type = "range",
					order = get_order(),
					name = L["Width"],
					min = 10,
					max = 500,
					step = 0.1,
					get = function () return RemUplift.db.profile.upliftBarWidth end,
					set = function (_, v)
						RemUplift.db.profile.upliftBarWidth = v
						RemUplift:UpdateUpliftStatusBarSize()
					end
				},
				BarHeight =
				{
					type = "range",
					order = get_order(),
					name = L["Height"],
					min = 10,
					max = 500,
					step = 0.1,
					get = function () return RemUplift.db.profile.upliftBarHeight end,
					set = function (_, v)
						RemUplift.db.profile.upliftBarHeight = v
						RemUplift:UpdateUpliftStatusBarSize()
					end
				},
				Percentage =
				{
					order = get_order(),
					type = "description",
					name = L["Percentage"],
					fontSize = "medium",
					width = "full",
				},
				PercentageFont =
				{
					type = 'select',
					dialogControl = 'LSM30_Font',
					name = L["Font"],
					values = LSM:HashTable("font"),
					order = get_order(),
					get = function()
						return RemUplift.db.profile.upliftPercentageFont
					end,
					set = function(_,v)
						RemUplift.db.profile.upliftPercentageFont = v
						RemUplift:UpdateUpliftPercentageFont()
					end,
				},
				PercentageFontSize =
				{
					type = "range",
					order = get_order(),
					name = L["Font Size"],
					min = 0.1,
					max = 500,
					step = 0.1,
					get = function () return RemUplift.db.profile.upliftPercentageFontSize end,
					set = function (_, v)
						RemUplift.db.profile.upliftPercentageFontSize = v
						RemUplift:UpdateUpliftPercentageFont()
					end
				},
				Amount =
				{
					order = get_order(),
					type = "description",
					name = L["Amount"],
					fontSize = "medium",
					width = "full",
				},
				AmountFont =
				{
					type = 'select',
					dialogControl = 'LSM30_Font',
					name = L["Font"],
					values = LSM:HashTable("font"),
					order = get_order(),
					get = function()
						return RemUplift.db.profile.upliftAmountFont
					end,
					set = function(_,v)
						RemUplift.db.profile.upliftAmountFont = v
						RemUplift:UpdateUpliftAmountFont()
					end,
				},
				AmountFontSize=
				{
					type = "range",
					order = get_order(),
					name = L["Font Size"],
					min = 0.1,
					max = 500,
					step = 0.1,
					get = function () return RemUplift.db.profile.upliftAmountFontSize end,
					set = function (_, v)
						RemUplift.db.profile.upliftAmountFontSize = v
						RemUplift:UpdateUpliftAmountFont()
					end
				},
			}
		},
		
		EL =
		{
			order = get_order(),
			name = GetSpellInfo(185158),
			type = "group",
			args =
			{ 
				LeftPos = 
				{
					type = "range",
					order = get_order(),
					name = L["Left Position"],
					min = 0,
					max = cvar_width,
					step = 0.1,
					get = function () return RemUplift.db.profile.extendLifeCounterPosLeft end,
					set = function (_, v)
						RemUplift.db.profile.extendLifeCounterPosLeft = v
						RemUplift:UpdateELIconPosition()
					end
				},
				TopPos = 
				{
					type = "range",
					order = get_order(),
					name = L["Top Position"],
					min = 0,
					max = cvar_height,
					step = 0.1,
					get = function () return RemUplift.db.profile.extendLifeCounterPosTop end,
					set = function (_, v)
						RemUplift.db.profile.extendLifeCounterPosTop = v
						RemUplift:UpdateELIconPosition()
					end
				},
				IconSize =
				{
					type = "range",
					order = get_order(),
					name = L["Size"],
					min = 10,
					max = cvar_min,
					step = 0.1,
					get = function () return RemUplift.db.profile.extendLifeIconSize end,
					set = function (_, v)
						RemUplift.db.profile.extendLifeIconSize = v
						RemUplift:UpdateELIconSize()
					end
				},
				Counter =
				{
					order = get_order(),
					type = "description",
					name = L["Counter"],
					fontSize = "medium",
					width = "full",
				},
				CounterFont =
				{
					type = 'select',
					dialogControl = 'LSM30_Font',
					name = L["Font"],
					values = LSM:HashTable("font"),
					order = get_order(),
					get = function()
						return RemUplift.db.profile.extendLifeCounterFont
					end,
					set = function(_,v)
						RemUplift.db.profile.extendLifeCounterFont = v
						RemUplift:UpdateELCounterFont()
					end,
				},
				CounterFontSize =
				{
					type = "range",
					order = get_order(),
					name = L["Font Size"],
					min = 0.1,
					max = 100,
					step = 0.1,
					get = function () return RemUplift.db.profile.extendLifeCounterFontSize end,
					set = function (_, v)
						RemUplift.db.profile.extendLifeCounterFontSize = v
						RemUplift:UpdateELCounterFont()
					end
				},
				MinDuration =
				{
					order = get_order(),
					type = "description",
					name = L["Min Duration"],
					fontSize = "medium",
					width = "full",
				},
				MinDurationFont =
				{
					type = 'select',
					dialogControl = 'LSM30_Font',
					name = L["Font"],
					values = LSM:HashTable("font"),
					order = get_order(),
					get = function()
						return RemUplift.db.profile.extendLifeMinDurationFont
					end,
					set = function(_,v)
						RemUplift.db.profile.extendLifeMinDurationFont = v
						RemUplift:UpdateELMinDurationFont()
					end,
				},
				MinDurationFontSize =
				{
					type = "range",
					order = get_order(),
					name = L["Font Size"],
					min = 0.1,
					max = 100,
					step = 0.1,
					get = function () return RemUplift.db.profile.extendLifeMinDurationFontSize end,
					set = function (_, v)
						RemUplift.db.profile.extendLifeMinDurationFontSize = v
						RemUplift:UpdateELMinDurationFont()
					end
				},
			}
		},
		ELUplift =
		{
			order = get_order(),
			name = string_format(L["%s(%s)"],GetSpellInfo(116670),GetSpellInfo(185158)),
			type = "group",
			args =
			{
				LeftPos = 
				{
					type = "range",
					order = get_order(),
					name = L["Left Position"],
					min = 0,
					max = cvar_width,
					step = 0.1,
					get = function () return RemUplift.db.profile.upliftELPosLeft end,
					set = function (_, v)
						RemUplift.db.profile.upliftELPosLeft = v
						RemUplift:UpdateUpliftELStatusBarPosition()
					end
				},
				TopPos = 
				{
					type = "range",
					order = get_order(),
					name = L["Top Position"],
					min = 0,
					max = cvar_height,
					step = 0.1,
					get = function () return RemUplift.db.profile.upliftELPosTop end,
					set = function (_, v)
						RemUplift.db.profile.upliftELPosTop = v
						RemUplift:UpdateUpliftELStatusBarPosition()
					end
				},
				BarWidth =
				{
					type = "range",
					order = get_order(),
					name = L["Width"],
					min = 10,
					max = 500,
					step = 0.1,
					get = function () return RemUplift.db.profile.upliftELBarWidth end,
					set = function (_, v)
						RemUplift.db.profile.elupliftBarWidth = v
						RemUplift:UpdateUpliftELStatusBarSize()
					end
				},
				BarHeight =
				{
					type = "range",
					order = get_order(),
					name = L["Height"],
					min = 10,
					max = 500,
					step = 0.1,
					get = function () return RemUplift.db.profile.upliftELBarHeight end,
					set = function (_, v)
						RemUplift.db.profile.upliftELBarHeight = v
						RemUplift:UpdateUpliftELStatusBarSize()
					end
				},
				Percentage =
				{
					order = get_order(),
					type = "description",
					name = L["Percentage"],
					fontSize = "medium",
					width = "full",
				},
				PercentageFont =
				{
					type = 'select',
					dialogControl = 'LSM30_Font',
					name = L["Font"],
					values = LSM:HashTable("font"),
					order = get_order(),
					get = function()
						return RemUplift.db.profile.upliftELPercentageFont
					end,
					set = function(_,v)
						RemUplift.db.profile.upliftELPercentageFont = v
						RemUplift:UpdateUpliftELPercentageFont()
					end,
				},
				PercentageFontSize =
				{
					type = "range",
					order = get_order(),
					name = L["Font Size"],
					min = 0.1,
					max = 500,
					step = 0.1,
					get = function () return RemUplift.db.profile.upliftELPercentageFontSize end,
					set = function (_, v)
						RemUplift.db.profile.upliftELPercentageFontSize = v
						RemUplift:UpdateUpliftELPercentageFont()
					end
				},
				Amount =
				{
					order = get_order(),
					type = "description",
					name = L["Amount"],
					fontSize = "medium",
					width = "full",
				},
				AmountFont =
				{
					type = 'select',
					dialogControl = 'LSM30_Font',
					name = L["Font"],
					values = LSM:HashTable("font"),
					order = get_order(),
					get = function()
						return RemUplift.db.profile.upliftELAmountFont
					end,
					set = function(_,v)
						RemUplift.db.profile.upliftELAmountFont = v
						RemUplift:UpdateUpliftELAmountFont()
					end,
				},
				AmountFontSize=
				{
					type = "range",
					order = get_order(),
					name = L["Font Size"],
					min = 0.1,
					max = 500,
					step = 0.1,
					get = function () return RemUplift.db.profile.upliftELAmountFontSize end,
					set = function (_, v)
						RemUplift.db.profile.upliftELAmountFontSize = v
						RemUplift:UpdateUpliftELAmountFont()
					end
				},
			}
		},
		Calculation =
		{
			order = get_order(),
			name = L["Calculation"],
			type = "group",
			args =
			{
				WorldPVP =
				{
					order = get_order(),
					name = L["World PVP"],
					desc = string_format(L["Using Events to help us trace %s. Disabling it may improve performance"],GetSpellInfo(115151))
					type = "toggle",
					set = function(info,val)
						RemUplift.db.profile.worldPVP = val
						RemUplift:UpdateWorldPVP()
					end,
					get = function(info) return RemUplift.db.profile.worldPVP end,
				},
				AutoHide =
				{
					order = get_order(),
					name = L["Auto Hide"],
					type = "toggle",
					set = function(info,val)
						RemUplift.db.profile.autoHide = val
						RemUplift:UpdateAutoHide()
					end,
					get = function(info) return RemUplift.db.profile.autoHide end,
					width = "full",
				},
				Ashran =
				{
					order = get_order(),
					name = GetMapNameByID(978),
					type = "toggle",
					set = function(info,val)
						RemUplift.db.profile.ashran = val
						RemUplift:UpdateAshran()
					end,
					get = function(info) return RemUplift.db.profile.ashran end,
					width = "full",
				},
				EnableEL =
				{
					order = get_order(),
					name = GetSpellInfo(185158),
					type = "toggle",
					set = function(info,val)
						RemUplift.db.profile.extendLifeEnable = val
						RemUplift:UpdateEnableEL()
					end,
					get = function(info) return RemUplift.db.profile.extendLifeEnable end,
					width = "full",
				},
				UpliftPredictFactor=
				{
					type = "range",
					order = get_order(),
					name = L["Predict Factor"],
					min = 0.01,
					max = 10,
					step = 0.01,
					get = function () return RemUplift.db.profile.upliftPredictFactor end,
					set = function (_, v)
						RemUplift.db.profile.upliftPredictFactor = v
						RemUplift:UpdatePredictFactor()
					end,
					width = "full"
				},
			}
		},
	},
}

local optionsFrames = {}
function RemUplift_Options:OnInitialize()
	options.args.profile = AceDBOptions:GetOptionsTable(RemUplift.db)
	AceConfig:RegisterOptionsTable("RemUplift", options, nil)
	optionsFrames.general = AceConfigDialog:AddToBlizOptions("RemUplift", "RemUplift")
	RemUplift.db.RegisterCallback(RemUplift, "OnProfileChanged", "UpdateDB")
	RemUplift.db.RegisterCallback(RemUplift, "OnProfileCopied", "UpdateDB")
	RemUplift.db.RegisterCallback(RemUplift, "OnProfileReset", "UpdateDB")
end